# -*- coding: utf-8 -*-
# Copyright (C) 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

u"""
Translatable strings for Scribes.

This modules contains user visible string eligible for translation. The strings
are defined by a unique identifier or format:

	msgXXXX = u"string eligible for translation"

XXXX is a number between 0001 and 9999.

@author: Lateef Alabi-Oki
@organiation: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from locale import setlocale, LC_ALL, Error
from gettext import bindtextdomain, textdomain, gettext
from sys import argv
from os import path


def find_locale_folder():
	u"""
	Search for Scribes' data folder

	@return: path Scribes' data folder
	@rtype: string
	"""

	head, tail = path.split(path.split(path.abspath(argv[0]))[0])

	if tail ==  "bin":

		data_dir = path.join(head, "share")

		if path.exists(data_dir):

			return data_dir

	raise "FileNotFoundError", msg0131


try:

	setlocale(LC_ALL, "")

except Error:

	pass

locale_folder = find_locale_folder() + "/locale"
bindtextdomain("scribes", locale_folder)
textdomain("scribes")
_ = gettext

# From module about.py

msg0001 = _(u"Scribes is a text editor for GNOME.")

# From module accelerators.py

msg0002 = _(u"Cannot undo action")
msg0003 = _(u"Cannot redo action")

# From module lines.py

msg0004 = _(u"Deleted line %d")
msg0005 = _(u"Joined line %d to line %d")
msg0006 = _(u"No more lines to join")

# From module select.py

msg0007 = _(u"Selected word")
msg0008 = _(u"No word to select")
msg0009 = _("No text to select in line %d")
msg0010 = _(u"Selected line %d")
msg0011 = _(u"Selected paragraph")
msg0012 = _(u"No paragraph to select")
msg0013 = _(u"Selected sentence")
msg0014 = _(u"No sentence to select")

# From module case.py

msg0015 = _(u"No selection to change case")
msg0016 = _(u"Selected text is already uppercase")
msg0017 = _(u"Changed selected text from lowercase to uppercase")
msg0018 = _(u"Selected text is already lowercase")
msg0019 = _(u"Changed selected text from uppercase to lowercase")

# From module bracket.py

msg0020 = _(u"Found matching bracket")
msg0021 = _(u"No matching bracket found")

# From module editor_ng.py

msg0022 = _(u"Disabled spellchecking")
msg0023 = _(u"Enabled spellchecking")
msg0024 = _(u"Leave Fullscreen")

# From module editor_ng.py, fileloader.py, timeout.py

msg0025 = _(u"Unsaved Document")

# From module filechooser.py

msg0026 = _(u"Open Document")
msg0027 = _(u"All Documents")
msg0028 = _(u"Python Documents")
msg0029 = _(u"Text Documents")

# From module fileloader.py

msg0030 = _(u'Loaded file "%s"')
msg0031 = _(u"An decoding error occurred. The character encoding of the file \
you are trying to open is not recognized. Try opening the file with another \
character encoding")
msg0032 = _(u"Loading file please wait...")
msg0033 = _(u"An error occurred while openning the file. Please file a bug \
report at http://scribes.sourceforge.net")

# From module fileloader.py, savechooser.py

msg0034 = _(u" <READONLY>")

# From module fileloader.py

msg0035 = _(u"You do not have permission to view this file.")
msg0036 = _(u"A file check error occurred. The file you are trying to open is \
not a text file.")
msg0037 = _(u"The file you are trying to open does not exist.")

# From module main.py

msg0038 = _("Unrecognized option: '%s'")
msg0039 = _("Try 'scribes --help' for more information")
msg0040 = _("Scribes only supports using one option at a time")
msg0041 = _("scribes: %s takes no arguments")
msg0042 = _("Scribes version %s")
msg0043 = _("%s does not exist")

# From module timeout.py

msg0044 = _(u'The file "%s" is open in readonly mode')
msg0045 = _(u'The file "%s" is open')

# From modules findbar.py

msg0046 = _(u"No match was found")
msg0047 = _(u"%d match was found")
msg0048 = _(u"%d matches were found")
msg0049 = _(u"_Search for:    ")
msg0050 = _(u"_Search for:")
msg0051 = _(u"_Previous")
msg0052 = _(u"_Next")
msg0053 = _(u"Match _case")
msg0054 = _(u"Match _word")

# From modules gotobar.py

msg0055 = _("Line number:")
msg0056 = _(" of %d")

# From module help.py

msg0057 = _(u"Launching help browser")

# From module indent.py

msg0058 = _(u"No indentation selection found")
msg0059 = _(u"Selection indented")
msg0060 = _(u"Unindentation is not possible")
msg0061 = _(u"Selection unindented")

# From module modes.py

msg0062 = _(u"loading...")

# From module preferences.py

msg0063 = _(u"<b>Font</b>")
msg0064 = _(u"Editor _font: ")
msg0065 = _(u"<b>Tab Stops</b>")
msg0066 = _(u"_Tab width: ")
msg0067 = _(u"<b>Text Wrapping</b>")
msg0068 = _(u"Enable text _wrapping")
msg0069 = _(u"<b>Right Margin</b>")
msg0070 = _(u"Display right _margin")
msg0071 = _(u"_Right margin position: ")
msg0072 = _(u"<b>Spell Checking</b>")
msg0073 = _(u"_Enable spell checking")

# From modules printing.py

msg0074 = _(u"Print Preview")
msg0075 = _(u"File: ")
msg0076 = _(u"Print Document")

# From module replace.py

msg0077 = _(u'"%s" has been replaced with "%s"')
msg0078 = _(u'Replaced all occurrences of "%s" with "%s"')
msg0079 = _(u"Replac_e with:")
msg0080 = _(u"_Replace")
msg0081 = _(u"Replace _All")

# From module savechooser.py

msg0082 = _(u"Save Document")

# From module savefile.py

msg0083 = _(u"An error occurred while saving this file.")
msg0084 = _(u'An error occurred while decoding your file. Please file a bug \
report at "http://openusability.org/forum/?group_id=141"')
msg0085 = _(u'Saved "%s"')

# From module textview.py

msg0086 = _(u"Shift _Right")
msg0087 = _(u"Shift _Left")
msg0088 = _(u"_Find Matching Bracket")
msg0089 = _(u"Copied selected text")
msg0090 = _(u"No selection to copy")
msg0091 = _(u"Cut selected text")
msg0092 = _(u"No selection to cut")
msg0093 = _(u"Pasted copied text")
msg0094 = _(u"No text content in the clipboard")

# From module timeout.py

msg0095 = _(u"%d%% complete")
msg0096 = _(u"completed")

# From module tooltips.py

msg0097 = _(u"Create a new file")
msg0098 = _(u"Open a file")
msg0099 = _(u"Change the name of current file and save it")
msg0100 = _(u"Print the current file")
msg0101 = _(u"Undo last action")
msg0102 = _(u"Redo undone action")
msg0103 = _(u"Search for text")
msg0104 = _(u"Search for and replace text")
msg0105 = _(u"Go to a specific line")
msg0106 = _(u"Configure the editor")
msg0107 = _(u"Launch the help browser")
msg0108 = _(u"Search for previous occurrence of the string")
msg0109 = _(u"Search for next occurrence of the string")
msg0110 = _(u"Find occurrences of the string that match upper and lower cases \
only")
msg0111 = _(u"Find occurrences of the string that match the entire word only")
msg0112 = _(u"Type in the text you want to search for")
msg0113 = _(u"Type in the text you want to replace with")
msg0114 = _(u"Replace the selected found match")
msg0115 = _(u"Replace all found matches")
msg0116 = _(u"Click to specify the font type, style, and size to use for text.")
msg0117 = _(u"Click to specify the width of the space that is inserted when \
you press the Tab key.")
msg0118 = _(u"Select to wrap text onto the next line when you reach the \
text window boundary.")
msg0119 = _(u"Select to display a vertical line that indicates the right \
margin.")
msg0120 = _(u"Click to specify the location of the vertical line.")
msg0121 = _(u"Select to enable spell checking")

# From module undo_redo.py

msg0122 = _(u"Undid last action")
msg0123 = _(u"Redid undone action")

# From module usage.py

msg0124 = _("A text editor for GNOME.")
msg0125 = _("usage: scribes [OPTIONS] [FILE] [...]")
msg0126 = _("Options:")
msg0127 = _("display this help screen")
msg0128 = _("output version information of Scribes")
msg0129 = _("create a new file and open the file with Scribes")
msg0130 = _("open file in readonly mode")

# From module utility.py

msg0131 = _(u"Could not find Scribes' data folder")

# From preferences.py

msg0132 = _(u"Preferences")

# From error.py

msg0133 = _(u"error")

# From module indent.py

msg0134 = _(u"No spaces were found at end of line")
msg0135 = _(u"Removed spaces at end of line")

# From module lines.py

msg0136 = _(u"Freed line %d")
msg0137 = _(u"Deleted text from cursor to end of line")
msg0138 = _(u"Cursor is already at the end of line")
msg0139 = _(u"Deleted text from cursor to beginning of line")
msg0140 = _(u"Cursor is already at the beginning of line")

# From module indent.py

msg0141 = _(u"No spaces were found at beginning of line")
msg0142 = _(u"Removed spaces at beginning of line")
msg0143 = _(u"Removed spaces at beginning of selected lines")
msg0144 = _(u"Removed spaces at end of selected lines")

# From module actions.py

msg0145 = _(u"Cannot perform operation in readonly mode")

# From module indent.py

msg0146 = _(u"Indented line %d")
msg0147 = _(u"Unindented line %d")
msg0148 = _(u"No selected lines can be indented")

# From module case.py

msg0149 = _(u"Swapped the case of selected text")
msg0150 = _(u"Capitalized selected text")
msg0151 = _(u"Selected text is already capitalized")

# From module savefile.py

msg0152 = _(u"An error occurred while encoding your file. Try saving your \
file using another character encoding, preferably UTF-8.")

# From module fileloader.py

msg0153 = _(u"An encoding error occurred. Please file a bug report at \
http://openusability.org/forum/?group_id=141")

# From brackets.py

msg0154 = _(u"Bracket completion occurred")

# From autocomplete.py

msg0155 = _(u"Word completion occurred")

# From brackets.py

msg0156 = _(u"Removed bracket completion")

# From encoding.py

msg0157 = _(u"_Character Encoding: ")
msg0158 = _(u"Add or Remove Encoding")
msg0159 = _(u"Recommended (UTF-8)")
msg0160 = _(u"Add or Remove Character Encoding")
msg0161 = _(u"Language and Region")
msg0162 = _(u"Character Encoding")
msg0163 = _(u"Select")

# From bookmark.py

msg0164 = _(u"Line %d is already bookmarked")
msg0165 = _(u"Bookmarked line %d")
msg0166 = _(u"No bookmark on line %d to remove")
msg0167 = _(u"Removed bookmark on line %d")
msg0168 = _(u"No bookmarks found to remove")
msg0169 = _(u"Removed all bookmarks")
msg0170 = _(u"No next bookmark to move to")
msg0171 = _(u"Moved to bookmark on line %d")
msg0172 = _(u"No previous bookmark to move to")

# From filechooser.py, savechooser.py

msg0173 = _(u"Select character _encoding")



