# -*- coding: utf-8 -*-
# Copyright (C) 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

u"""
Toolbar object for the editor created via uimanager

"""

from gtk import UIManager, RESIZE_IMMEDIATE, TOOLBAR_ICONS

from utility import find_toolbar_folder

################################################################################
#
#							UIManager Callback
#
################################################################################


def uimanager_cb(uimanager, widget, editor):
	u"""
	Handles callback when toolbar is updated

	@param uimanager:	uimanager object
	@type uimanager:	uimanager object
	@param widget:		toolbar object
	@type widget:		toolbar object
	@param editor:		Reference to the editor instance
	@type editor:			An editor object

	"""

	editor.uimanager.ensure_update()

	return


################################################################################
#
#								Toolbar
#
################################################################################


def create_toolbar(editor):
	u"""
	Create a toolbar object

	@param editor:	Reference to the editor instance
	@type editor:	An editor object

	@return:		A toolbar object
	@rtype:			A GTK+ Toolbar

	"""

	# Create a UIManager instance

	uimanager = UIManager()
	editor.uimanager = uimanager
	uimanager.connect(u"add-widget", uimanager_cb, editor)

	# Add the actiongroup to the uimanager

	uimanager.insert_action_group(editor.actiongroup, 0)

	# Merge the User Interface

	toolbar_folder = find_toolbar_folder()
	uifile = toolbar_folder + u"/scribes_toolbar_ui.xml"
	uimanager.add_ui_from_file(uifile)

	# Create Toolbar

	toolbar = uimanager.get_widget(u"/toolbar")

	# Set Container Properties

	toolbar.set_resize_mode(RESIZE_IMMEDIATE)
	toolbar.set_style(TOOLBAR_ICONS)

	# Make Undo and Redo Toolbuttons insensitive by default

	editor.actiongroup.get_action(u"undo_edits").set_sensitive(False)
	editor.actiongroup.get_action(u"redo_edits").set_sensitive(False)

	return toolbar