# -*- coding: utf-8 -*-
# Copyright (C) 2005 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

u"""
Undo/Redo module for scribes.

@author: Lateef Alabi-Oki
@organiation: The Scribes Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com

"""

from utility import update_status_info
from internationalization import msg0122, msg0123

################################################################################
#
#								Undo
#
################################################################################


def undo_action(editor):
	u"""
	Undo an activity that occurred in the buffer.

	@param editor: editor
	@type editor: editor object

	"""

	if editor.text_buffer.can_undo():


		# We use this flag to fool and prevent the editor from switching to edit
		# mode when the user types into the buffer.

		editor.mode_edit_flag = True
		editor.text_buffer.undo()
		cursor_mark = editor.text_buffer.get_insert()
		editor.text_view.scroll_to_mark(cursor_mark, 0.3,
								      use_align=False, xalign=0.5,
								      yalign=0.5)
		update_status_info(editor, msg0122, "undo")

	else:

		editor.actiongroup.get_action(u"undo_edits").set_sensitive(False)

	return


################################################################################
#
#								Redo
#
################################################################################


def redo_action(editor):
	u"""
	Redo an undone activity that occurred in the buffer.

	@param editor: editor
	@type editor: editor object

	"""

	if editor.text_buffer.can_redo():

		# We use this flag to fool and prevent the editor from switching to edit
		# mode when the user types into the buffer.

		editor.mode_edit_flag = True
		editor.text_buffer.redo()
		cursor_mark = editor.text_buffer.get_insert()
		editor.text_view.scroll_to_mark(cursor_mark, 0.3,
								 	  use_align=False, xalign=0.5,
								      yalign=0.5)
		update_status_info(editor, msg0123, "redo")

	else:

		editor.actiongroup.get_action(u"redo_edits").set_sensitive(False)

	return